export interface Message {
    messageType: string;
    [key: string]: unknown;
}
export declare function isMessage(message: any): message is Message;
export interface CommandMessage extends Message {
    messageType: 'command';
    command: string;
}
export declare function isCommandMessage(message: Message): message is CommandMessage;
export interface ServiceConfiguration {
    serviceType: string;
    serviceId: string;
    remoteServiceId: string;
}
export interface CreatePeerConnectionMessage extends CommandMessage {
    command: 'createPeerConnection';
    connectiontype: string;
    connectionUrl: string;
    services: ServiceConfiguration[];
    tiebreaker: boolean;
}
export declare function isCreatePeerConnectionMessage(message: CommandMessage): message is CreatePeerConnectionMessage;
export interface SignalingMessage extends Message {
    messageType: 'signaling';
    connectionUrl: string;
}
export declare function isSignalingMessage(message: Message): message is SignalingMessage;
export interface ServiceDescription {
    serviceType: string;
    serviceId: string;
    serviceDirection: string;
    interfaces: unknown[];
}
export interface DeviceDescription {
    services: ServiceDescription[];
}
export interface ClosePeerConnectionMessage extends CommandMessage {
    command: 'closePeerconnection';
    connectionUrl: string;
}
export declare function isClosePeerConnectionMessage(message: CommandMessage): message is ClosePeerConnectionMessage;
export interface ConnectionStateChangedMessage extends Message {
    messageType: 'connection-state-changed';
    connectionUrl: string;
    status: 'new' | 'connecting' | 'connected' | 'disconnected' | 'failed' | 'closed';
}
export interface ConfigurationMessage extends Message {
    messageType: 'configuration';
    configuration: {
        [k: string]: unknown;
    };
}
export declare function isConfigurationMessage(message: Message): message is ConfigurationMessage;
export interface ExperimentStatusChangedMessage extends Message {
    messageType: 'experiment-status-changed';
    status: 'created' | 'booked' | 'setup' | 'running' | 'failed' | 'closed';
    message?: string;
}
export declare function isExperimentStatusChangedMessage(message: Message): message is ExperimentStatusChangedMessage;
//# sourceMappingURL=deviceMessages.d.ts.map